@@ -51,7 +51,9 @@ if(plot) {#curve(cos((*x-fit[1,1])*s.resp+m.resp)*pi/12),add=TRUE) } #this draws
    code))], "phase",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
    code))], "fit",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
    code))], "amp",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
-   code))], "sd",sep=".")) 
+   code))], "sd",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "mean",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "intercept",sep=".")) 
    rownames(fit) <- names(fit.list) 
  }
  x <- NA   #just to avoid being told that x is a global 
@@ -66,7 +68,7 @@ function(angle,x,period=24,opti=FALSE,na.rm=TRUE) {
 response <- x
 n.var <- dim(x)[2]
 if(is.null(n.var)) n.var <-1 
-fit <- matrix(NaN,nrow=n.var,ncol=4)
+fit <- matrix(NaN,nrow=n.var,ncol=6)
 for (i in 1:n.var) {
 if(opti) {fits <- optimize(f=phaser,c(0,24),time=angle,response=x[,i],period=period,maximum=TRUE)  #iterative fit 
 fit[i,1] <- fits$maximum
@@ -76,9 +78,11 @@ fit[i,2] <- fits$objective
    fit[i,2] <- fits[[2]]  #this is the correlation of the fit with the data  
    fit[i,3] <- fits[[3]]   #this is the amplitude
    fit[i,4] <- fits[[4]]  #The standard deviation of the observed scores
+   fit[i,5] <- fits[[5]]  #the mean of the observed scores 
+   fit[i,6] <- fits[[6]]  #the predicted value of the observed score at the intercept 
    }
 }
-colnames(fit) <- c("phase","fit","amplitude","sd")
+colnames(fit) <- c("phase","fit","amplitude","sd","mean","intercept")
 rownames(fit) <- colnames(x)
 return(fit)
 }
@@ -88,7 +92,7 @@ return(fit)
  
    
 #the alternative to the iterative procedure is simple linear regression of the cosine and sine    
-   "cosinor.lm2" <- 
+"cosinor.lm2" <- 
 function(angle,y,period=24,na.rm=na.rm) {
  p2 <- period/2
         cos.t <- cos(angle)  #angle is already in radians!
@@ -99,15 +103,20 @@ function(angle,y,period=24,na.rm=na.rm) {
     beta2 <- (cor.dat[3,2] - cor.dat[3,1] * cor.dat[1,2])/(cor.dat[1,1]-cor.dat[1,2]^2)
      
    #  phase <- ( sign(beta2) *acos( beta1/sqrt(beta1^2 + beta2^2)))*p2/pi #this is in hours
-     phase <- atan2(beta2,beta1)*p2/pi  #this is better because of the problem of exactly pi offset
+     phase <- atan2(beta2,beta1)  #in radians
+     intercept <- cos(phase)   #the value at time 0
+     phase <- phase *p2/pi  #convert to hours
      phase <- phase  %% period
      r <-  cor(cos(angle-phase*pi/p2),y,use="pairwise") 
-     sdy <-  sd(y,na.rm=TRUE)
-     amp <- r *sdy/.7223
+     sdy <-  sd(y,na.rm=na.rm)
+     meany <- mean(y,na.rm=na.rm)
+     #amp <- r *sdy/.7223
+     amp <- sqrt(beta1^2 + beta2^2) #see Chow 2009 among others
+     intercept <- intercept * amp * sdy  + meany
      #amp <- r * sd(y,na.rm=TRUE)/sd(cos(angle[,1]),na.rm=TRUE)
     #R <- sqrt(cor.dat[3,1]*beta1 + cor.dat[3,2]*beta2)  #these are identical
-   
-    fit <- list(phase=phase,R=r,amp=amp,sd=sdy)
+    
+    fit <- list(phase=phase,R=r,amp=amp,sd=sdy,mean=meany,intercept)
     
 return(fit)
 }
@@ -148,7 +157,8 @@ sd.time <- sd(cos(angle[,1]),na.rm=TRUE)
 if(missing(ylim)) ylim=c(min(x[,2],(m.resp - fit[1,3]),na.rm=na.rm),max(x[,2],(m.resp + fit[1,3]),na.rm=na.rm))
 main <- paste(main," ",round(fit[1,1],2))
 # plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ="l",ylim=ylim,...)
- plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*fit[1,3]/(sqrt(2)*.7223)+ m.resp,typ="l",ylim=ylim,ylab=ylab,xlab=xlab,main=main,...)
+# plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*fit[1,3]*s.resp+ m.resp,typ="l",ylim=ylim,ylab=ylab,xlab=xlab,main=main,...)
+plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ="l",ylim=ylim,ylab=ylab,xlab=xlab,main=main,...)
 points(c(x[,1],x[,1] + 24),rep(x[,2],2))
 
 #this draws the first fitted variable
