@@ -63,65 +63,89 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
     	
     colnames(loadings) <- paste("PC",1:nfactors,sep='')
     rownames(loadings) <- rownames(r)
-  Phi <- NULL   
+  Phi <- NULL  
+  
+     rot.mat <- NULL 
  if(rotate != "none") {if (nfactors > 1) {
 if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" | rotate =="targetT" | rotate =="bifactor"   | rotate =="TargetT"|
                        rotate =="equamax"| rotate =="varimin"|rotate =="specialT" | rotate =="Promax"  | rotate =="promax"| rotate =="cluster" |rotate == "biquartimin" |rotate == "TargetQ"  |rotate =="specialQ" ) {
-
+Phi <- NULL 
 switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psych
   varimax = {rotated <- stats::varimax(loadings)  #varimax is from stats, the others are from GPArotation 
-   			         loadings <- rotated$loadings},
+   			         loadings <- rotated$loadings
+   			         rot.mat <- rotated$rotmat},
    Varimax = {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	       #varimax is from the stats package, Varimax is from GPArotations
    			#rotated <- do.call(rotate,list(loadings,...))
    			#rotated <- do.call(getFromNamespace(rotate,'GPArotation'),list(loadings,...))
    			rotated <- GPArotation::Varimax(loadings)
-   			loadings <- rotated$loadings} ,
+   			loadings <- rotated$loadings
+   			 rot.mat <- t(solve(rotated$Th))} ,
    	quartimax = {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	      
    			#rotated <- do.call(rotate,list(loadings))
    			rotated <- GPArotation::quartimax(loadings)
-   			loadings <- rotated$loadings} ,
+   			loadings <- rotated$loadings
+   			 rot.mat <- t(solve(rotated$Th))} ,
    	bentlerT =  {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	       
    			#rotated <- do.call(rotate,list(loadings,...))
    			rotated <- GPArotation::bentlerT(loadings)
-   			loadings <- rotated$loadings} ,
+   			loadings <- rotated$loadings
+   			 rot.mat <- t(solve(rotated$Th))} ,
    	geominT	= {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	      
    			#rotated <- do.call(rotate,list(loadings,...))
    			rotated <- GPArotation::geominT(loadings)
-   			loadings <- rotated$loadings} ,
+   			loadings <- rotated$loadings
+   			 rot.mat <- t(solve(rotated$Th))} ,
    	targetT = {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
-   	     
-   			#rotated <- do.call(rotate,list(loadings,...))
-   			rotated <- GPArotation::targetT(loadings)
-   			loadings <- rotated$loadings} ,
+   			rotated <- GPArotation::targetT(loadings,Tmat=diag(ncol(loadings)),...)
+   			loadings <- rotated$loadings
+   			 rot.mat <- t(solve(rotated$Th))} ,
    			
-   	 bifactor = {loadings <- bifactor(loadings)$loadings},    #corrected 16/06/15 to actually return the appropriate value rather than the unrotated solution
-   	 TargetT =  {loadings <- TargetT(loadings,...)$loadings},  #reported by Matthias Bellmann
-   	equamax =  {loadings <- equamax(loadings)$loadings}, 
-   	varimin = {loadings <- varimin(loadings)$loadings},
-   	specialT =  {loadings <- specialT(loadings)$loadings}, 
+   	 bifactor = {rot <- bifactor(loadings)
+   	             loadings <- rot$loadings
+   	            rot.mat <- t(solve(rot$Th))},  
+   	 TargetT =  {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
+   	            rot <- GPArotation::targetT(loadings,Tmat=diag(ncol(loadings)),...)
+   	              loadings <- rot$loadings
+   	            rot.mat <- t(solve(rot$Th))},
+   	equamax =  {rot <- equamax(loadings)
+   	              loadings <- rot$loadings
+   	            rot.mat <- t(solve(rot$Th))}, 
+   	varimin = {rot <- varimin(loadings)
+   	            loadings <- rot$loadings
+   	            rot.mat <- t(solve(rot$Th))},
+   	specialT =  {rot <- specialT(loadings)
+   	              loadings <- rot$loadings
+   	              rot.mat <- t(solve(rot$Th))}, 
    	Promax =   {pro <- Promax(loadings)
+     			loadings <- pro$loadings
+     			 Phi <- pro$Phi 
+     			 rot.mat <- pro$rotmat},
+     promax =   {pro <- stats::promax(loadings)   #from stats
      			 loadings <- pro$loadings
-     			  Phi <- pro$Phi },
-     promax =   {pro <- Promax(loadings)
-     			 loadings <- pro$loadings
-     			  Phi <- pro$Phi },	
+     			  rot.mat <- pro$rotmat
+     			  ui <- solve(rot.mat)
+     			  Phi <-  cov2cor(ui %*% t(ui))},	
      cluster = 	 {loadings <- varimax(loadings)$loadings           			
 								pro <- target.rot(loadings)
      			              	loadings <- pro$loadings
-     			                Phi <- pro$Phi},
+     			                Phi <- pro$Phi
+     			                 rot.mat <- pro$rotmat},
      biquartimin =    {ob <- biquartimin(loadings,)
                     loadings <- ob$loadings
-     				 Phi <- ob$Phi}, 
+     				 Phi <- ob$Phi
+     				 rot.mat <- t(solve(ob$Th))}, 
      TargetQ  =  {ob <- TargetQ(loadings,...)
                     loadings <- ob$loadings
-     				 Phi <- ob$Phi}, 
+     				 Phi <- ob$Phi
+     				  rot.mat <- t(solve(ob$Th))}, 
      specialQ = {ob <- specialQ(loadings,...)
                     loadings <- ob$loadings
-     				 Phi <- ob$Phi})
+     				 Phi <- ob$Phi
+     				 rot.mat <- t(solve(pro$Th))})
      } else {
      #The following oblique cases all use GPArotation			                
      if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax" | rotate =="geominQ"  | rotate =="bentlerQ"  |rotate == "targetQ"  ) {
@@ -133,9 +157,12 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
      				               ob <- Promax(loadings)}
      				                 
      				loadings <- ob$loadings
-     				 Phi <- ob$Phi}
+     				 Phi <- ob$Phi
+     				  rot.mat <- t(solve(ob$Th))}
      		                             } else {message("Specified rotation not found, rotate='none' used")}
-     	 } }}
+     	 }
+     	} 
+     	 }
      	 		
    #just in case the rotation changes the order of the components, sort them by size of eigen value
    if(nfactors >1) {
@@ -183,6 +210,7 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
     result$PVAL <-  stats$PVAL
     result$weights <-  stats$weights
     result$r.scores <-  stats$r.scores
+     result$rot.mat <- rot.mat
     if(!is.null(Phi) && oblique.scores) {
                        result$Structure <- loadings %*% Phi} else {result$Structure <- loadings
                        }
